==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/pt-ST.pl <==
{
  am_pm_abbreviated => [
    "a.m.",
    "p.m."
  ],
  available_formats => {
    E => "ccc",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM 'de' y G",
    GyMMMEd => "E, d 'de' MMM 'de' y G",
    GyMMMd => "d 'de' MMM 'de' y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd/MM",
    MMM => "LLL",
    MMMEd => "E, d/MM",
    MMMMEd => "ccc, d 'de' MMMM",
    "MMMMW-count-one" => "W.'\N{U+00aa}' 'semana' 'de' MMM",
    "MMMMW-count-other" => "W.'\N{U+00aa}' 'semana' 'de' MMM",
    MMMMd => "d 'de' MMMM",
    MMMd => "d/MM",
    MMdd => "dd/MM",
    Md => "dd/MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E, dd/MM/y",
    yMM => "MM/y",
    yMMM => "MM/y",
    yMMMEEEEd => "EEEE, d/MM/y",
    yMMMEd => "E, d/MM/y",
    yMMMM => "MMMM 'de' y",
    yMMMMEd => "ccc, d 'de' MMMM 'de' y",
    yMMMMd => "d 'de' MMMM 'de' y",
    yMMMd => "d/MM/y",
    yMd => "dd/MM/y",
    yQQQ => "QQQQ 'de' y",
    yQQQQ => "QQQQ 'de' y",
    "yw-count-one" => "w.'\N{U+00aa}' 'semana' 'de' y",
    "yw-count-other" => "w.'\N{U+00aa}' 'semana' 'de' y"
  },
  code => "pt-ST",
  date_format_full => "EEEE, d 'de' MMMM 'de' y",
  date_format_long => "d 'de' MMMM 'de' y",
  date_format_medium => "dd/MM/y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} '\N{U+00e0}s' {0}",
  datetime_format_long => "{1} '\N{U+00e0}s' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "segunda",
    "ter\N{U+00e7}a",
    "quarta",
    "quinta",
    "sexta",
    "s\N{U+00e1}bado",
    "domingo"
  ],
  day_format_narrow => [
    "S",
    "T",
    "Q",
    "Q",
    "S",
    "S",
    "D"
  ],
  day_format_wide => [
    "segunda-feira",
    "ter\N{U+00e7}a-feira",
    "quarta-feira",
    "quinta-feira",
    "sexta-feira",
    "s\N{U+00e1}bado",
    "domingo"
  ],
  day_stand_alone_abbreviated => [
    "segunda",
    "ter\N{U+00e7}a",
    "quarta",
    "quinta",
    "sexta",
    "s\N{U+00e1}bado",
    "domingo"
  ],
  day_stand_alone_narrow => [
    "S",
    "T",
    "Q",
    "Q",
    "S",
    "S",
    "D"
  ],
  day_stand_alone_wide => [
    "segunda-feira",
    "ter\N{U+00e7}a-feira",
    "quarta-feira",
    "quinta-feira",
    "sexta-feira",
    "s\N{U+00e1}bado",
    "domingo"
  ],
  era_abbreviated => [
    "a.C.",
    "d.C."
  ],
  era_narrow => [
    "a.C.",
    "d.C."
  ],
  era_wide => [
    "antes de Cristo",
    "depois de Cristo"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%d-%m-%Y",
  glibc_datetime_format => "%a %d %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Portuguese",
  month_format_abbreviated => [
    "jan",
    "fev",
    "mar",
    "abr",
    "mai",
    "jun",
    "jul",
    "ago",
    "set",
    "out",
    "nov",
    "dez"
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_format_wide => [
    "janeiro",
    "fevereiro",
    "mar\N{U+00e7}o",
    "abril",
    "maio",
    "junho",
    "julho",
    "agosto",
    "setembro",
    "outubro",
    "novembro",
    "dezembro"
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "fev",
    "mar",
    "abr",
    "mai",
    "jun",
    "jul",
    "ago",
    "set",
    "out",
    "nov",
    "dez"
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_stand_alone_wide => [
    "janeiro",
    "fevereiro",
    "mar\N{U+00e7}o",
    "abril",
    "maio",
    "junho",
    "julho",
    "agosto",
    "setembro",
    "outubro",
    "novembro",
    "dezembro"
  ],
  name => "Portuguese S\N{U+00e3}o Tom\N{U+00e9} & Pr\N{U+00ed}ncipe",
  native_language => "portugu\N{U+00ea}s",
  native_name => "portugu\N{U+00ea}s S\N{U+00e3}o Tom\N{U+00e9} e Pr\N{U+00ed}ncipe",
  native_script => undef,
  native_territory => "S\N{U+00e3}o Tom\N{U+00e9} e Pr\N{U+00ed}ncipe",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "1.\N{U+00ba} trimestre",
    "2.\N{U+00ba} trimestre",
    "3.\N{U+00ba} trimestre",
    "4.\N{U+00ba} trimestre"
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "1.\N{U+00ba} trimestre",
    "2.\N{U+00ba} trimestre",
    "3.\N{U+00ba} trimestre",
    "4.\N{U+00ba} trimestre"
  ],
  script => undef,
  territory => "S\N{U+00e3}o Tom\N{U+00e9} & Pr\N{U+00ed}ncipe",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.26.tar.gz: DateTime-Locale-1.26/share/pt-ST.pl <==
{
  am_pm_abbreviated => [
    "a.m.",
    "p.m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM 'de' y G",
    GyMMMEd => "E, d 'de' MMM 'de' y G",
    GyMMMd => "d 'de' MMM 'de' y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd/MM",
    MMM => "LLL",
    MMMEd => "E, d/MM",
    MMMMEd => "ccc, d 'de' MMMM",
    "MMMMW-count-one" => "W.'\N{U+00aa}' 'semana' 'de' MMMM",
    "MMMMW-count-other" => "W.'\N{U+00aa}' 'semana' 'de' MMMM",
    MMMMd => "d 'de' MMMM",
    MMMd => "d/MM",
    MMdd => "dd/MM",
    Md => "dd/MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E, dd/MM/y",
    yMM => "MM/y",
    yMMM => "MM/y",
    yMMMEEEEd => "EEEE, d/MM/y",
    yMMMEd => "E, d/MM/y",
    yMMMM => "MMMM 'de' y",
    yMMMMEd => "ccc, d 'de' MMMM 'de' y",
    yMMMMd => "d 'de' MMMM 'de' y",
    yMMMd => "d/MM/y",
    yMd => "dd/MM/y",
    yQQQ => "QQQQ 'de' y",
    yQQQQ => "QQQQ 'de' y",
    "yw-count-one" => "w.'\N{U+00aa}' 'semana' 'de' Y",
    "yw-count-other" => "w.'\N{U+00aa}' 'semana' 'de' Y",
  },
  code => "pt-ST",
  date_format_full => "EEEE, d 'de' MMMM 'de' y",
  date_format_long => "d 'de' MMMM 'de' y",
  date_format_medium => "dd/MM/y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} '\N{U+00e0}s' {0}",
  datetime_format_long => "{1} '\N{U+00e0}s' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "segunda",
    "ter\N{U+00e7}a",
    "quarta",
    "quinta",
    "sexta",
    "s\N{U+00e1}bado",
    "domingo",
  ],
  day_format_narrow => [
    "S",
    "T",
    "Q",
    "Q",
    "S",
    "S",
    "D",
  ],
  day_format_wide => [
    "segunda-feira",
    "ter\N{U+00e7}a-feira",
    "quarta-feira",
    "quinta-feira",
    "sexta-feira",
    "s\N{U+00e1}bado",
    "domingo",
  ],
  day_stand_alone_abbreviated => [
    "segunda",
    "ter\N{U+00e7}a",
    "quarta",
    "quinta",
    "sexta",
    "s\N{U+00e1}bado",
    "domingo",
  ],
  day_stand_alone_narrow => [
    "S",
    "T",
    "Q",
    "Q",
    "S",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "segunda-feira",
    "ter\N{U+00e7}a-feira",
    "quarta-feira",
    "quinta-feira",
    "sexta-feira",
    "s\N{U+00e1}bado",
    "domingo",
  ],
  era_abbreviated => [
    "a.C.",
    "d.C.",
  ],
  era_narrow => [
    "a.C.",
    "d.C.",
  ],
  era_wide => [
    "antes de Cristo",
    "depois de Cristo",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%d-%m-%Y",
  glibc_datetime_format => "%a %d %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Portuguese",
  month_format_abbreviated => [
    "jan.",
    "fev.",
    "mar.",
    "abr.",
    "mai.",
    "jun.",
    "jul.",
    "ago.",
    "set.",
    "out.",
    "nov.",
    "dez.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "janeiro",
    "fevereiro",
    "mar\N{U+00e7}o",
    "abril",
    "maio",
    "junho",
    "julho",
    "agosto",
    "setembro",
    "outubro",
    "novembro",
    "dezembro",
  ],
  month_stand_alone_abbreviated => [
    "jan.",
    "fev.",
    "mar.",
    "abr.",
    "mai.",
    "jun.",
    "jul.",
    "ago.",
    "set.",
    "out.",
    "nov.",
    "dez.",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "janeiro",
    "fevereiro",
    "mar\N{U+00e7}o",
    "abril",
    "maio",
    "junho",
    "julho",
    "agosto",
    "setembro",
    "outubro",
    "novembro",
    "dezembro",
  ],
  name => "Portuguese S\N{U+00e3}o Tom\N{U+00e9} & Pr\N{U+00ed}ncipe",
  native_language => "portugu\N{U+00ea}s",
  native_name => "portugu\N{U+00ea}s S\N{U+00e3}o Tom\N{U+00e9} e Pr\N{U+00ed}ncipe",
  native_script => undef,
  native_territory => "S\N{U+00e3}o Tom\N{U+00e9} e Pr\N{U+00ed}ncipe",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1.\N{U+00ba} trimestre",
    "2.\N{U+00ba} trimestre",
    "3.\N{U+00ba} trimestre",
    "4.\N{U+00ba} trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1.\N{U+00ba} trimestre",
    "2.\N{U+00ba} trimestre",
    "3.\N{U+00ba} trimestre",
    "4.\N{U+00ba} trimestre",
  ],
  script => undef,
  territory => "S\N{U+00e3}o Tom\N{U+00e9} & Pr\N{U+00ed}ncipe",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 37,
}
